@@ -14,6 +14,6 @@ __PACKAGE__->columns(Essential => qw(category_id date_created fk1 fk2 fk3 id las
 
 __PACKAGE__->has_a(category_id => 'MyTest::CDBI::Simple::Category');
 
-__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Simple::CodeName');
+__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Simple::CodeName', { cascade => 'None' });
 
 1;
\ No newline at end of file
