@@ -14,7 +14,7 @@ __PACKAGE__->columns(Essential => qw(category_id date_created fk1 fk2 fk3 id las
 
 __PACKAGE__->has_a(category_id => 'MyTest::CDBI::Sweet::Simple::Category');
 
-__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Sweet::Simple::CodeName');
+__PACKAGE__->has_many(code_names => 'MyTest::CDBI::Sweet::Simple::CodeName', { cascade => 'None' });
 
 # Dunno why I have to do this, but it doesn't work without it...
 my $meta = __PACKAGE__->meta_info(has_many => 'code_names');
