@@ -34,6 +34,16 @@ __PACKAGE__->meta->foreign_keys
   }
 );
 
+__PACKAGE__->meta->relationships
+(
+  code_names =>
+  {
+    type  => 'one to many',
+    class => 'MyTest::RDBO::Simple::CodeName',
+    column_map => { id => 'product_id' },
+  }
+);
+
 __PACKAGE__->meta->auto_initialize;
 
 1;
\ No newline at end of file
